#! /bin/bash

set -e

. /usr/share/debconf/confmodule
db_version 2.0
db_capb backup

LICENSE=ttf-msfonts-v1-0

db_get ttf-msfonts/accepted-$LICENSE
if [ "$RET" = "true" ]; then
    echo "$LICENSE license has already been accepted" >&2
    exit 0
fi



# summary of how this script can be called:
#        * <new-preinst> `install'
#        * <new-preinst> `install' <old-version>
#        * <new-preinst> `upgrade' <old-version>
#        * <old-preinst> `abort-upgrade' <new-version>
#
# for details, see http://www.debian.org/doc/debian-policy/ or
# the debian-policy package

PACKAGE_NAME=ttf-msfonts-nonfree
PRODUCT_NAME="Microsoft TrueType Fonts"

case "$1" in
    install|upgrade)
        # Allow the user to go back and forward, per debconf-devel(7)
        STATE=1
        while true; do
            case "$STATE" in
                0) # Allow the user to backup from license presentation
                    STATE=1
                    continue
                    ;;
                1) # Present the license
                    db_fset ttf-msfonts/present-$LICENSE seen false
                    if ! db_input critical ttf-msfonts/present-$LICENSE ; then
                        echo "$license license could not be presented; aborting" >&2
                        exit 2
                    fi
                    db_fset ttf-msfonts/accepted-$LICENSE seen false
                    if ! db_input critical ttf-msfonts/accepted-$LICENSE ; then
                        echo "$license agree question could not be asked; aborting" >&2
                        exit 2
                    fi
                    ;;
                2) # Check the user's acceptance
                    db_get ttf-msfonts/accepted-$LICENSE
                    if [ "$RET" = "true" ]; then
                        # License accepted.
                        break # Breaks out of the while loop
                    fi
                    # Error on declining the license; give the user the chance to back up.
                    db_input critical ttf-msfonts/error-$license
                    ;;
                3) # User has confirmed declining license
                    exit 1
                    ;;
                *)
                    echo "$license license state unknown: $STATE" >&2
                    exit 2
                    ;;
            esac

            if db_go; then
                 STATE=$(($STATE + 1))
            else 
                 STATE=$(($STATE - 1))
            fi
        done
    ;;

    abort-upgrade)
    ;;

    *)
        echo "preinst called with unknown argument \`$1'" >&2
        exit 1
    ;;
esac

# dh_installdeb will replace this with shell code automatically
# generated by other debhelper scripts.



exit 0


